Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::iterator_range< I, S > Member List

This is the complete list of members for ranges::v3::iterator_range< I, S >, including all inherited members.

at(range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n]) | ranges::v3::view_interface< iterator_range< I, S > > |
at(range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n]) | ranges::v3::view_interface< iterator_range< I, S > > |
back() | ranges::v3::view_interface< iterator_range< I, S > > |
back() const | ranges::v3::view_interface< iterator_range< I, S > > |
derived() noexcept (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > | protected
derived() const noexcept | ranges::v3::view_interface< iterator_range< I, S > > | protected
empty() const (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
front() | ranges::v3::view_interface< iterator_range< I, S > > |
front() const | ranges::v3::view_interface< iterator_range< I, S > > |
iterator typedef (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
iterator_range()=default (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
iterator_range(I begin, S end) (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
iterator_range(iterator_range< X, Y > rng) (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
iterator_range(std::pair< X, Y > rng) (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > | explicit
operator bool() const noexcept(noexcept(ranges::empty(std::declval< D const & >()))) (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > | explicit
operator Container() | ranges::v3::view_interface< iterator_range< I, S > > |
operator Container() const | ranges::v3::view_interface< iterator_range< I, S > > |
operator std::pair< X, Y >() const (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
operator!() const noexcept(noexcept(decltype(ranges::empty(std::declval< D const & >()))(ranges::empty(std::declval< D const & >())))) -> decltype(ranges::empty(std::declval< D const & >())) (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
operator=(iterator_range< X, Y > rng) (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
operator=(view_interface &&)=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
operator=(view_interface const &)=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n]) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n]) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< iterator_range< I, S > > |
sentinel typedef (defined in ranges::v3::iterator_range< I, S >) | ranges::v3::iterator_range< I, S > |
size() const noexcept | ranges::v3::view_interface< iterator_range< I, S > > |
size() const (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
view_interface()=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
view_interface(view_interface &&)=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
view_interface(view_interface const &)=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > |
~view_interface()=default (defined in ranges::v3::view_interface< iterator_range< I, S > >) | ranges::v3::view_interface< iterator_range< I, S > > | protected